==> haskell-wl-pprint-extras-3.5.0.5-33-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-wl-pprint-extras.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wl-pprint-extras
version: 3.5.0.5
id: wl-pprint-extras-3.5.0.5-LUcQ1bB9Kn9L7HML45cAPE
key: wl-pprint-extras-3.5.0.5-LUcQ1bB9Kn9L7HML45cAPE
license: BSD3
copyright: Copyright (C) 2011-2012 Edward A. Kmett,
           Copyright (C) 2000 Daan Leijen
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: experimental
homepage: http://github.com/ekmett/wl-pprint-extras/
synopsis: A free monad based on the Wadler/Leijen pretty printer
description:
    A free monad based on the Wadler/Leijen pretty printer
category: Control, Monads, Text
author: Edward A. Kmett
exposed: True
indefinite: False
exposed-modules:
    Text.PrettyPrint.Free Text.PrettyPrint.Free.Internal
abi: 36ce53614cff7a74a651f6a1fdd15faf
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/wl-pprint-extras-3.5.0.5
library-dirs: /usr/lib/ghc-8.2.2/site-local/wl-pprint-extras-3.5.0.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/wl-pprint-extras-3.5.0.5
hs-libraries: HSwl-pprint-extras-3.5.0.5-LUcQ1bB9Kn9L7HML45cAPE
depends:
    base-4.10.1.0 containers-0.5.10.2
    semigroups-0.18.4-mxkGq2xNPcBC0dj8uuk3q
    semigroupoids-5.2.2-FDF6D6Ndk4K3Ji4q4rZOo
    utf8-string-1.0.1.1-7sQ7eR5H5ED7poickls5aO
    text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             semigroups-0.18.4-mxkGq2xNPcBC0dj8uuk3q=0f8a4b2bc8ee8ce3a5dab66f0eb14e7c
             semigroupoids-5.2.2-FDF6D6Ndk4K3Ji4q4rZOo=90fdd869255a98b23f946f5c8be29ab5
             utf8-string-1.0.1.1-7sQ7eR5H5ED7poickls5aO=4a40da384793deade7b4b9c9224acdb7
             text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz=29872508833c96394f0471371217bab0
haddock-interfaces: /usr/share/doc/haskell-wl-pprint-extras/html/wl-pprint-extras.haddock
haddock-html: /usr/share/doc/haskell-wl-pprint-extras/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wl-pprint-extras-3.5.0.5-34-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-wl-pprint-extras.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wl-pprint-extras
version: 3.5.0.5
id: wl-pprint-extras-3.5.0.5-L382masGWE8Gsi2Zy72FZl
key: wl-pprint-extras-3.5.0.5-L382masGWE8Gsi2Zy72FZl
license: BSD3
copyright: Copyright (C) 2011-2012 Edward A. Kmett,
           Copyright (C) 2000 Daan Leijen
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: experimental
homepage: http://github.com/ekmett/wl-pprint-extras/
synopsis: A free monad based on the Wadler/Leijen pretty printer
description:
    A free monad based on the Wadler/Leijen pretty printer
category: Control, Monads, Text
author: Edward A. Kmett
exposed: True
indefinite: False
exposed-modules:
    Text.PrettyPrint.Free Text.PrettyPrint.Free.Internal
abi: 955558cc4b4274101767093f304d458b
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/wl-pprint-extras-3.5.0.5
library-dirs: /usr/lib/ghc-8.2.2/site-local/wl-pprint-extras-3.5.0.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/wl-pprint-extras-3.5.0.5
hs-libraries: HSwl-pprint-extras-3.5.0.5-L382masGWE8Gsi2Zy72FZl
depends:
    base-4.10.1.0 containers-0.5.10.2
    semigroups-0.18.4-mxkGq2xNPcBC0dj8uuk3q
    semigroupoids-5.2.2-980gUPpFb7yG9re08jralN
    utf8-string-1.0.1.1-7sQ7eR5H5ED7poickls5aO
    text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             semigroups-0.18.4-mxkGq2xNPcBC0dj8uuk3q=0f8a4b2bc8ee8ce3a5dab66f0eb14e7c
             semigroupoids-5.2.2-980gUPpFb7yG9re08jralN=52e886195f289832052b200dd3f6f093
             utf8-string-1.0.1.1-7sQ7eR5H5ED7poickls5aO=4a40da384793deade7b4b9c9224acdb7
             text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz=29872508833c96394f0471371217bab0
haddock-interfaces: /usr/share/doc/haskell-wl-pprint-extras/html/wl-pprint-extras.haddock
haddock-html: /usr/share/doc/haskell-wl-pprint-extras/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
